@@ -1,6 +1,3 @@
-use crate::errors::ParseError;
-
-use super::enums::Symbol;
 use super::ident_parser::Rule;
 use pest::iterators::Pair;
 use std::collections::HashSet;
@@ -67,34 +64,16 @@ fn escape_chars(source: &str) -> String {
     escaped_source
 }
 
-pub fn symbol_variants(
-    negative: bool,
-    negative_allowed: bool,
-    positive_variant: Symbol,
-    negative_variant: Option<Symbol>,
-) -> Result<Symbol, ParseError> {
-    if negative && !negative_allowed {
-        return Err(ParseError {
-            message: format!("negative {:?} not allowed", positive_variant),
-        });
-    }
-    if negative {
-        Ok(negative_variant.unwrap())
-    } else {
-        Ok(positive_variant)
-    }
-}
-
 /// maps over the items in `iterable` with `closure`,
 /// returning a vector of `ReturnItem` or an `Error`
 /// if one of the calls to `closure` returns an `Error`
 pub fn map_results<Iterable, Item, Closure, ReturnItem, Error>(
     iterable: Iterable,
-    closure: Closure,
+    closure: &mut Closure,
 ) -> Result<Vec<ReturnItem>, Error>
 where
     Iterable: Iterator<Item = Item>,
-    Closure: Fn(Item) -> Result<ReturnItem, Error>,
+    Closure: FnMut(Item) -> Result<ReturnItem, Error>,
 {
     let mut output = vec![];
     for item in iterable {
